@@ -150,6 +150,15 @@ static struct {
 	{ "undisclosed-recipients",
 	  "undisclosed-recipients",
 	  "undisclosed-recipients" },
+	/* The following 2 addr-specs are invalid according to the
+	 * spec, but apparently some japanese cellphones use them?
+	 * See Evolution bug #547969 */
+	{ "some...dots@hocus.pocus.net",
+	  "some...dots@hocus.pocus.net",
+	  "some...dots@hocus.pocus.net" },
+	{ "some.dots..@hocus.pocus.net",
+	  "some.dots..@hocus.pocus.net",
+	  "some.dots..@hocus.pocus.net" },
 };
 
 static void
@@ -165,7 +174,7 @@ test_addrspec (void)
 		
 		testsuite_check ("addrspec[%u]", i);
 		try {
-			if (!(addrlist = internet_address_parse_string (addrspec[i].input)))
+			if (!(addrlist = internet_address_list_parse_string (addrspec[i].input)))
 				throw (exception_new ("could not parse addr-spec"));
 			
 			str = internet_address_list_to_string (addrlist, FALSE);
